aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/ops.c
diff options
context:
space:
mode:
authorJustin M. Keyes <justinkz@gmail.com>2017-02-18 23:15:27 +0100
committerJustin M. Keyes <justinkz@gmail.com>2017-02-18 23:24:35 +0100
commitbaab49ee89a927f63bfefdb432155a1037afa93a (patch)
tree23da98828033f05ee78d9b406504dabd6fc9f77c /src/nvim/ops.c
parent308ccb6f5e40ba1dbe4abfebc9df3399d7f17504 (diff)
downloadrneovim-baab49ee89a927f63bfefdb432155a1037afa93a.tar.gz
rneovim-baab49ee89a927f63bfefdb432155a1037afa93a.tar.bz2
rneovim-baab49ee89a927f63bfefdb432155a1037afa93a.zip
cmdline: CTRL-R: Omit trailing <CR>.
The "technically correct" interpretation is to execute the first line that is seen (and this is what happens on middle-click paste in Vim). ^M is only intended to "defuse" the newline, so the user can review it. The parent commit changed the behavior to insert <Space> between lines, but that's a higher-risk change: it is arguably possible that some user *wants* the literal ^M chars when e.g. assigning to a register: :let @a='<C-R>b' To avoid that risk, keep the old behavior and only omit the last ^M. This makes `yy:<C-R>0` nicer at no cost.
Diffstat (limited to 'src/nvim/ops.c')
-rw-r--r--src/nvim/ops.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/nvim/ops.c b/src/nvim/ops.c
index 2f45795812..8bfda3c193 100644
--- a/src/nvim/ops.c
+++ b/src/nvim/ops.c
@@ -1266,10 +1266,10 @@ int get_spec_reg(
///
/// @param regname Register name.
/// @param literally Insert text literally instead of "as typed".
/// @param remspc When true, don't add <Space> characters.
///
/// @returns FAIL for failure, OK otherwise
-bool cmdline_paste_reg(int regname, bool literally, bool remspc)
+bool cmdline_paste_reg(int regname, bool literally, bool remcr)
{
yankreg_T *reg = get_yank_register(regname, YREG_PASTE);
if (reg->y_array == NULL)
@@ -1278,9 +1278,9 @@ bool cmdline_paste_reg(int regname, bool literally, bool remspc)
for (size_t i = 0; i < reg->y_size; i++) {
cmdline_paste_str(reg->y_array[i], literally);
- // Insert space between lines, unless `remspc` is true.
- if (i < reg->y_size - 1 && !remspc) {
- cmdline_paste_str((char_u *)" ", literally);
+ // Insert ^M between lines, unless `remcr` is true.
+ if (i < reg->y_size - 1 && !remcr) {
+ cmdline_paste_str((char_u *)"\r", literally);
}
/* Check for CTRL-C, in case someone tries to paste a few thousand
@@ -1266,10 +1266,10 @@ int get_spec_reg(
/// @param regname Register name.
/// @param literally Insert text literally instead of "as typed".
-/// @param remspc When true, don't add <Space> characters.
+/// @param remcr When true, don't add CR characters.
///
/// @returns FAIL for failure, OK otherwise